summaryrefslogtreecommitdiff
path: root/lldb/source/Expression/IRMemoryMap.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lldb/source/Expression/IRMemoryMap.cpp')
-rw-r--r--lldb/source/Expression/IRMemoryMap.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/lldb/source/Expression/IRMemoryMap.cpp b/lldb/source/Expression/IRMemoryMap.cpp
index 26e59b76a4da..f978217fa8f2 100644
--- a/lldb/source/Expression/IRMemoryMap.cpp
+++ b/lldb/source/Expression/IRMemoryMap.cpp
@@ -637,19 +637,19 @@ void IRMemoryMap::WriteScalarToMemory(lldb::addr_t process_address,
}
void IRMemoryMap::WritePointerToMemory(lldb::addr_t process_address,
- lldb::addr_t address, Status &error) {
+ lldb::addr_t pointer, Status &error) {
error.Clear();
/// Only ask the Process to fix the address if this address belongs to the
/// process. An address belongs to the process if the Allocation policy is not
/// eAllocationPolicyHostOnly.
- auto it = FindAllocation(address, 1);
+ auto it = FindAllocation(pointer, 1);
if (it == m_allocations.end() ||
it->second.m_policy != AllocationPolicy::eAllocationPolicyHostOnly)
if (auto process_sp = GetProcessWP().lock())
- address = process_sp->FixAnyAddress(address);
+ pointer = process_sp->FixAnyAddress(pointer);
- Scalar scalar(address);
+ Scalar scalar(pointer);
WriteScalarToMemory(process_address, scalar, GetAddressByteSize(), error);
}
@@ -637,19 +637,19 @@ void IRMemoryMap::WriteScalarToMemory(lldb::addr_t process_address,
error.Clear();
- /// Only ask the Process to fix the address if this address belongs to the
+ /// Only ask the Process to fix `pointer` if the address belongs to the
/// process. An address belongs to the process if the Allocation policy is not
/// eAllocationPolicyHostOnly.